Extension traits and helpers for GPUI keymap integration
Structs
- Binding
Builder - Helper to create multiple bindings with the same context
Functions
- bind
- Helper to create a single binding
- create_
bindings - Helper to create a list of key bindings from action-keystroke pairs