pub struct KeymapCollection { /* private fields */ }Expand description
A collection of keymaps, typically loaded from multiple files
Implementations
Sourceimpl KeymapCollection
impl KeymapCollection
Sourcepub fn load_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>
pub fn load_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>
Load a keymap from a JSON file
Sourcepub fn load_defaults(&mut self) -> Result<()>
pub fn load_defaults(&mut self) -> Result<()>
Load default keymaps
Sourcepub fn get_binding_specs(&self) -> Vec<BindingSpec>
pub fn get_binding_specs(&self) -> Vec<BindingSpec>
Get all key binding specifications from this collection
Returns a list of binding specifications that can be used to create actual GPUI key bindings with concrete action types.
Sourcepub fn find_bindings_for_action(&self, action_name: &str) -> Vec<BindingSpec>
pub fn find_bindings_for_action(&self, action_name: &str) -> Vec<BindingSpec>
Find all bindings for a given action