Module extensions

Module extensions 

Extension traits and helpers for GPUI keymap integration

Structs

BindingBuilder
Helper to create multiple bindings with the same context

Functions

bind
Helper to create a single binding
create_bindings
Helper to create a list of key bindings from action-keystroke pairs